/**
 *	@file NPWGraphics.c
 *	@brief Helper functions for graphics
 *	@author Yves Piguet.
 *	@copyright 2008-2013, Yves Piguet.
 */

/* License: new BSD license (see header file) */

#include "NPWGraphics.h"
#include <stdarg.h>

/// Check error returned by a function and returns it unless kNPWErrOk
#define Chk(e) \
	do { \
		err = (e); \
		if (err != kNPWErrOk) \
			return err; \
	} while (0)


NPWErr NPWGraphicsCmd(NPW *pdf, NPWConstText cmd, NPWConstText fmt, ...)
{
	va_list ap;
	NPWErr err = kNPWErrOk;
	NPWConstText str;
	NPWInt len;
	
	va_start(ap, fmt);
	while (*fmt)
	{
		switch (*fmt++)
		{
			case 'f':	// float
#if !defined(NPWNoFloat)
				err = NPWWriteFloat(pdf, va_arg(ap, NPWFloat));
				break;
#endif
			case 'i':	// integer
				err = NPWWriteInt(pdf, va_arg(ap, NPWInt), -1);
				break;
			case 'S':	// raw string
				str = va_arg(ap, NPWConstText);
				len = va_arg(ap, NPWInt);
				err = NPWWrite(pdf, str, len);
				break;
			case 's':	// string
				str = va_arg(ap, NPWConstText);
				len = va_arg(ap, NPWInt);
				err = NPWWriteString(pdf, str, len);
				break;
			case '[':	// array delimiter
			case ']':
				err = NPWWrite(pdf, &fmt[-1], 1);
				break;
		}
		if (err == kNPWErrOk)
			err = NPWWrite(pdf, " ", 1);
		if (err != kNPWErrOk)
			break;
	}
	va_end(ap);
	
	if (err != kNPWErrOk)
		return err;
	
	Chk(NPWWrite(pdf, cmd, -1));
	Chk(NPWWrite(pdf, "\n", -1));
	return kNPWErrOk;
}
