/**
 *	@file NPWInfo.c
 *	@brief Helper functions for document information
 *	@author Yves Piguet.
 *	@copyright 2008-2013, Yves Piguet.
 */

/* License: new BSD license (see header file) */

#include "NPWInfo.h"

/// Check error returned by a function and returns it unless kNPWErrOk
#define Chk(e) \
	do { \
		err = (e); \
		if (err != kNPWErrOk) \
			return err; \
	} while (0)

static NPWConstText kDataKeyInfo = "info";

static NPWErr infoWriteDict(NPW *pdf, void *userData)
{
	NPWRef ref;
	NPWConstText addr, value;
	NPWInt len;
	NPWBoolean hasBegun = FALSE;
	NPWErr err;
	(void)userData;
	
	addr = NULL;
	for (;;)
	{
		if (NPWDataGetNext(pdf, kDataKeyInfo, (void **)&addr) != kNPWErrOk)
			break;
		
		if (!hasBegun)
		{
			// at least one info: write header
			Chk(NPWBeginObj(pdf, &ref));
			Chk(NPWWrite(pdf, "<<\n", -1));
			pdf->info = ref;
			hasBegun = TRUE;
		}
		
		// write info entry
		Chk(NPWWrite(pdf, "/", -1));
		for (len = 0; addr[len] != '\0'; len++)
			;
		Chk(NPWWrite(pdf, addr, len));
		value = addr + len + 1;
		Chk(NPWWrite(pdf, " ", -1));
		for (len = 0; value[len] != '\0'; len++)
			;
		Chk(NPWWriteString(pdf, value, len));
		Chk(NPWWrite(pdf, "\n", -1));
	}
	if (hasBegun)
	{
		Chk(NPWWrite(pdf, ">>\n", -1));
		Chk(NPWEndObj(pdf));
	}
	
	return kNPWErrOk;
}

NPWErr NPWInfoAddEntry(NPW *pdf, NPWConstText key, NPWConstText value)
{
	NPWInt size, i, j;
	NPWText addr;
	NPWErr err;
	
	// install callback if it's the first one
	if (NPWDataGetNth(pdf, kDataKeyInfo, 0, (void **)&addr) != kNPWErrOk)
		Chk(NPWAddDelayedActionCB(pdf, infoWriteDict, NULL));
	
	// get total size
	for (i = 0; key[i] != '\0'; i++)
		;
	size = i + 1;	// including terminator
	for (i = 0; value[i]; i++)
		;
	size += i + 1;	// including terminator
	
	// alloc new data
	Chk(NPWDataAlloc(pdf, kDataKeyInfo, size, (void **)&addr));
	
	// copy key and value
	for (i = 0; key[i]; i++)
		addr[i] = key[i];
	addr[i++] = '\0';
	for (j = 0; value[j]; j++)
		addr[i++] = value[j];
	addr[i] = '\0';
	
	return kNPWErrOk;
}
