/**
 *	@file NPWInfo.h
 *	@brief Helper functions for document information
 *	@author Yves Piguet.
 *	@copyright 2008-2013, Yves Piguet
 */

#ifndef __NPWInfo__
#define __NPWInfo__

#ifdef __cplusplus
extern "C" {
#endif

#include "NPWBase.h"

#define kNPWInfoKeyTitle "Title"	///< information title key
#define kNPWInfoKeyAuthor "Author"	///< information author key
#define kNPWInfoKeySubject "Subject"	///< information subject key
#define kNPWInfoKeyKeywords "Keywords"	///< information keywords key
#define kNPWInfoKeyCreator "Creator"	///< information creator key
#define kNPWInfoKeyProducer "Producer"	///< information producer key
#define kNPWInfoKeyCreationDate "CreationDate"	///< information creation and date key (date format: ISO/IEC 8824)
#define kNPWInfoKeyModDate "ModDate"	///< information modification date key (date format: ISO/IEC 8824)
#define kNPWInfoKeyTrapped "Trapped"	///< information trapped key

/**	Add an information dictionary entry.
	@param pdf reference to NPW structure
	@param[in] key entry key (kNPWInfoKeyTitle etc.)
	@param[in] value entry value (null-terminated string)
	@return error code (kNPWErrOk for success)
*/
NPWErr NPWInfoAddEntry(NPW *pdf, NPWConstText key, NPWConstText value);

#ifdef __cplusplus
}
#endif

#endif
