/**
 *	@file NPWMarkupTest.c
 *	@brief Test program for NPW Markup (convert text with markup to PDF).
 *	@author Yves Piguet.
 *	@copyright 2008-2013, Yves Piguet.
 */

/* License: new BSD license (see NPW.h) */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "NPWBase.h"
#include "NPWStdAlloc.h"
#include "NPWStdOutput.h"
#include "NPWGraphics.h"
#include "NPWInfo.h"
#include "NPWText.h"
#include "NPWTextMarkup.h"

static NPWMarkupCBEntry markupCBTable[] =
{
	{NPWMarkupCBCharStyle, NULL},
	{NULL, NULL}
};

/// Application entry point
int main(int argc, char **argv)
{
	NPW npw;
	NPWTextLayoutState state;
	NPWInt width, height;
	NPWInt leftmargin, rightmargin, topmargin, bottommargin;
	NPWFloat fontSize;
	NPWFloat lmw;
	NPWErr err;
	char *txt;
	int size, len, n;
	char str1[16];
	int page;
	
	// read stdin into txt
	size = 16384;
	txt = malloc(size);
	len = 0;
	for (;;)
	{
		n = fread(txt + len, 1, size - len, stdin);
		if (n < 0)
			break;
		len += n;
		if (len < size)	// eof
			break;
		size *= 2;
		txt = realloc(txt, size);
	}
	
	// set page size
	width = kNPWPaperWidthA4;
	height = kNPWPaperHeightA4;
	leftmargin = 25 * kNPWUnitMM;
	rightmargin = 25 * kNPWUnitMM;
	topmargin = 20 * kNPWUnitMM;
	bottommargin = 20 * kNPWUnitMM;
	fontSize = 12;
	lmw = kNPWPaperWidthA4 - leftmargin - rightmargin;
	
	NPWInit(&npw);
	NPWSetAllocCallback(&npw, NPWAllocStdlib, NULL);
	NPWSetWriteCallback(&npw, NPWWriteStdOutput, (void *)stdout);
	NPWTextLayoutInit(&state, markupCBTable);	// NULL for no markup
	NPWTextLayoutSetText(&state, txt, len);
	NPWTextLayoutSetBottom(&state, bottommargin);
	page = 0;
	
	do
	{
		NPWBeginPage(&npw, width, height);
		
		NPWTextLayoutSetPosition(&state, leftmargin, height - topmargin);
		NPWTextLayoutSetLineWidths(&state, &lmw, 1);
		err = NPWTextLayoutWrite(&npw, &state);
		
		NPWGraphicsBeginText(&npw);
		NPWGraphicsSetTextFont(&npw, NPWFontNameHelveticaBold, fontSize);
		NPWGraphicsGray(&npw, 0.6);
		NPWGraphicsMoveText(&npw,
				width - rightmargin / 2,
				2 * bottommargin);
		sprintf(str1, "%d", ++page);
		NPWGraphicsShowText(&npw, str1, -1);
		NPWGraphicsEndText(&npw);
		
		NPWEndPage(&npw);
	} while (err == kNPWErrIncomplete);
	
	NPWInfoAddEntry(&npw, kNPWInfoKeyCreator, "NPW (nyctergatis.com)");
	
	NPWTerminate(&npw);
	
	return 0;
}
