/**
 *	@file NPWTextMarkup.h
 *	@brief Simple text markup for PDF Output.
 *	@author Yves Piguet.
 *	@copyright 2008-2013, Yves Piguet.
 */

/* License: new BSD license (see NPW.h) */

/**	@page markup NPW Simple Text Markup
 *
 *	NPWTextMarkup.c defines simple text markup to format styled text
 *	with NPW. It requires NPWText.c.
 *
 *	The following tags are recognized in text passed to NPWTextLayoutSetText:
 *
 *	- \\\\ backslash
 *	- \\b bold on/off
 *	- \\i italic on/off
 *	- \\u underlined on/off
 *	- \\h hidden on/off
 *	- \\^ superscript on/off
 *	- \\_ subscript on/off
 *	- \\T Times
 *	- \\H Helvetica
 *	- \\C Courier
 *	- \\S Symbol
 *	- \\Z Zapf Dingbats
 *	- \\Ns font size N (N is an integer)
 *	- \\-s reset font size to default value
 *	- \\r flush right
 *	- \\l flush left
 *	- \\c center
 *	- \\j justify
 *	- \\N> indent first line by N (N is a positive or negative integer)
 *	- \\-> reset indent first line to default value
 *	- \\N+ indent all lines by N
 *	- \\-+ reset indent all lines to default value
 *	- \\NL line spacing N (N is an integer; 1000 = font size)
 *	- \\-L reset line spacing to default value
 *	- \\NK additional line spacing between paragraphs N (N is an integer; 1000 = font size)
 *	- \\-K reset additional line spacing between paragraphs to default value
 */

#if !defined(__NPWTextMarkup__)
#define __NPWTextMarkup__

#ifdef __cplusplus
extern "C" {
#endif

#include "NPWText.h"

/** Callback to decode text markup beginning with backslash.
	@param[in,out] userData callback-specific data (ignored)
	@param[in] t text whose beginning is analyzed
	@param[in] len length of t
	@param[out] count number of characters of markup
	@param[in,out] style character style
	@param[in,out] parFormat paragraph format
	@param[in] defaultStyle default character style
	@param[in] defaultParFormat default paragraph format
	@return kNPWMarkupActionFlagNotRecognized if no markup has been recognized, or
	flags describing the markup effect
*/
NPWMarkupActionFlag NPWMarkupCBCharStyle(void *userData,
		NPWConstText t, NPWInt len,
		NPWInt *count,
		NPWCharStyle *style,
		NPWParFormat *parFormat,
		NPWCharStyle const *defaultStyle,
		NPWParFormat const *defaultParFormat);

#ifdef __cplusplus
}
#endif

#endif
