/**
 *	@file NPWTransparency.h
 *	@brief Transparency-related functions for graphics
 *	@author Yves Piguet.
 *	@copyright 2011-2013, Yves Piguet
 */

#ifndef __NPWTransparency__
#define __NPWTransparency__

#ifdef __cplusplus
extern "C" {
#endif

#include "NPWBase.h"
#include "NPWGraphics.h"

#define kNPWBlendModeKeyNormal "Normal"	///< source color, ignoring the backdrop
#define kNPWBlendModeKeyMultiply "Multiply"	///< multiply source and backdrop (darken)
#define kNPWBlendModeKeyScreen "Screen"	///< multiply source and backdrop complements (lighten)
#define kNPWBlendModeKeyOverlay "Overlay"	///< overlay mode
#define kNPWBlendModeKeyDarken "Darken"	///< select the darker of the backdrop and source colors
#define kNPWBlendModeKeyLighten "Lighten"	///< select the lighter of the backdrop and source colors
#define kNPWBlendModeKeyColorDodge "ColorDodge"	///< brighten the backdrop to reflect the source color
#define kNPWBlendModeKeyColorBurn "ColorBurn"	///< darken the backdrop to reflect the source color
#define kNPWBlendModeKeyHardLight "HardLight"	///< hard light mode
#define kNPWBlendModeKeySoftLight "SoftLight"	///< soft light mode
#define kNPWBlendModeKeyDifference "Difference"	///< subtract the darker color from the lighter one
#define kNPWBlendModeKeyExclusion "Exclusion"	///< exclusion mode

/**	Set transparency parameters.
	@param pdf reference to NPW structure
	@param[in] strokingAlpha alpha constant used for stroking operations
	@param[in] nonStrokingAlpha alpha constant used for nonstroking operations
	@param[in] blendMode blend mode ()
	@param[in] fmt argument types (f=float, i=int, S=raw string+len, s=PDF string+len)
	@return error code (kNPWErrOk for success)
*/
NPWErr NPWGraphicsSetTransparency(NPW *pdf,
		NPWFloat strokingAlpha, NPWFloat nonStrokingAlpha,
		NPWConstText blendMode);

#ifdef __cplusplus
}
#endif

#endif
