/**
 *	@file PDFJpegWrapper.c
 *	@brief PDF wrapper for jpeg files based on NPW.
 *	@author Yves Piguet.
 *	@copyright 2012-2013, Yves Piguet.
 */

/* License: new BSD license (see NPW.h) */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "NPWBase.h"
#include "NPWGraphics.h"
#include "NPWStdAlloc.h"
#include "NPWStdOutput.h"
#include "NPWInfo.h"

#define kBufSize 256	///< buffer size used to copy stdin to PDF

/// Application entry point
int main(int argc, char **argv)
{
	NPW npw;
	int n;
	int width = kNPWPaperWidthA4, height = kNPWPaperHeightA4;
	NPWByte buf[kBufSize];
	
	if (argc >= 4 && !strcmp(argv[1], "--size"))
	{
		width = strtol(argv[2], NULL, 0);
		height = strtol(argv[3], NULL, 0);
	}
	
	NPWInit(&npw);
	NPWSetFonts(&npw, kNPWFontNone);
	NPWSetAllocCallback(&npw, NPWAllocStdlib, NULL);
	NPWSetWriteCallback(&npw, NPWWriteStdOutput, (void *)stdout);
	
	NPWBeginPage(&npw, width, height);
	NPWGraphicsSave(&npw);
	NPWGraphicsConcatCTM(&npw, width, 0, 0, height, 0, 0);
	NPWInlineImageBegin(&npw, width, height, "/RGB", 8, NPWFilterNameDCT);
	
	while (~feof(stdin))
	{
		n = fread(buf, 1, kBufSize, stdin);
		if (n <= 0)
			break;
		NPWWrite(&npw, buf, n);
	}
	
	NPWInlineImageEnd(&npw);
	NPWGraphicsRestore(&npw);
	NPWEndPage(&npw);
	
	NPWInfoAddEntry(&npw, kNPWInfoKeyCreator, "PDF JPEG Wrapper (nyctergatis.com)");
	
	NPWTerminate(&npw);
	
	return 0;
}
